@@ -21,7 +21,7 @@ import numpy as np
 from numpy.matlib import repmat
 from soundfile import read
 from midiutil import MIDIFile
-from pyanthem.misc import *
+#from pyanthem.pyanthem_vars import *
 
 def AE_download():
 	from git import Repo
@@ -36,6 +36,19 @@ def AE_download():
 	else:
 		print(f'Audio engine is already present in {AE_path}. If you want to uninstall, you must manually delete the AE folder.')
 
+def demodata_download():
+	from git import Repo
+	AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
+	if not os.path.isdir(AE_path):
+		print('Cloning the audio engine to the pyanthem package directory...')
+		try:
+			Repo.clone_from('https://github.com/nicthib/AE.git',AE_path)
+			print(f'Audio engine downloaded to {AE_path}')
+		except: # put exception type here
+			print('ERROR: git executable not present. Please visit https://git-scm.com/downloads to install.')
+	else:
+		print(f'Audio engine is already present in {AE_path}. If you want to uninstall, you must manually delete the AE folder.')
+
 def init_entry(fn):
 	if isinstance(fn, str):
 		entry = StringVar()
